`four_color` is a package for Four Color Problem.
::

* Download picture from https://www.dropbox.com/s/twiscp9h15so8no/sample.png?dl=1
* `python -m four_color`
* Open http://localhost:8000/
* Set "sample.png" and push "send" button.
* Download "fig.png".

.. image:: https://raw.githubusercontent.com/SaitoTsutomu/four_color/master/fig.gif
   :scale: 200%

Requirements
------------
* Python 3, Pillow, Flask, NetworkX, PuLP

Features
--------
* nothing

Setup
-----
::

   $ pip install four_color

History
-------
0.0.1 (2016-6-13)
~~~~~~~~~~~~~~~~~~
* first release
